%--------------------------------------------------------------
%
%  Modify child grid topography such that it matches the interpolated
%  parent topography at the boundaries.
%
%  This script is for use with make_roms2roms.
%
%   (c) 2007 Jeroen Molemaker, UCLA
%--------------------------------------------------------------
%
chdgrd=cgrid;
pargrd=pgrid;
% Only match to parent topography on open boundaries
%obcflag              = [1 0 1 1];      % open boundaries flag (1=open , [S E N W])


% End user-defined----------------------------------------------
%

% Get minimal parent subgrid bounds
lonc = ncread(chdgrd, 'lon_rho')';
latc = ncread(chdgrd, 'lat_rho')';

lonp = ncread(pargrd, 'lon_rho')';
latp = ncread(pargrd, 'lat_rho')';

lon0 = min(min(lonc));
lon1 = max(max(lonc));
lat0 = min(min(latc));
lat1 = max(max(latc));

g = lonp>=lon0&lonp<=lon1 & latp>=lat0&latp<=lat1;
jmin = min(find(any(g')));
jmax = max(find(any(g')));
imin = min(find(any(g)));
imax = max(find(any(g)));
clear g
lj = length(jmin:jmax);
li = length(imin:imax);

plot(lonp(jmin:jmax,imin:imax),latp(jmin:jmax,imin:imax),'.k')
hold on;plot(lonc,latc,'.r');hold off
drawnow

% Get topography data from childgrid
hc   = ncread(chdgrd, 'h')';
mask = ncread(chdgrd, 'mask_rho')';
[Mc,Lc]=size(hc);

% Get parent grid and squeeze minimal subgrid
hp    = ncread(pargrd, 'h')';
hp  = hp(jmin:jmax,imin:imax);
lonp    = ncread(pargrd, 'lon_rho')';
lonp= lonp(jmin:jmax,imin:imax);
latp    = ncread(pargrd, 'lat_rho')' ;
latp = latp(jmin:jmax,imin:imax);
maskp    = ncread(pargrd, 'mask_rho')';
maskp= maskp(jmin:jmax,imin:imax);
lonp(lonp<0) = lonp(lonp<0);

% Get interpolation coefficient to go to (lonc,latc).
[elem,coef] = get_tri_coef(lonp,latp,lonc,latc,maskp);
%% parent grid topo at child locations
hpi = sum(coef.*hp(elem),3);


if 0
    dist = zeros(Mc,Lc,4);
    for i = 1:Mc   %% north south
        for j = 1:Lc    %% east west
            dist(i,j,1) =      i/Mc + (1-obcflag(1))*1e6; % South
            dist(i,j,2) = (Lc-j)/Lc + (1-obcflag(2))*1e6; % East
            dist(i,j,3) = (Mc-i)/Mc + (1-obcflag(3))*1e6; % North
            dist(i,j,4) =      j/Lc + (1-obcflag(4))*1e6; % West
        end
    end
    dist = min(dist,[],3);
    
    alpha = 0.5*tanh(100*(dist-0.03))+0.5; %% Feel free to play with this function.
    alpha = 0.5*tanh( 50*(dist-0.06))+0.5; %% Feel free to play with this function.
else
    distance
end

hcn = alpha.*hc + (1-alpha).*hpi;

if 1
    ncwrite(chdgrd,'h',hcn');
    ncwriteatt(chdgrd,'h','notes1','Topo has been modified to match the parent grid topo at the boundaries');
end

%% Visualize the modification
  sc0 = min(min(hcn));
  sc1 = max(max(hcn));
  subplot(2,2,1)
  pcolor(lonc,latc,hpi);caxis([sc0 sc1]);colorbar;shading flat
  title('Interpolated Parent Topo')
  subplot(2,2,2)
  pcolor(lonc,latc,hcn);caxis([sc0 sc1]);colorbar;shading flat
  title('Boundary Smoothed Child Topo')
  subplot(2,2,3)
  pcolor(lonc,latc,hcn-hpi);colorbar;shading flat
  title('Difference between Parent and child Topo');
  subplot(2,2,4)
  pcolor(lonc,latc,alpha);colorbar;shading flat
  title('Parent/Child transition function');
