function roms2roms_coef_inter(par_grd,chd_grd,       ...
                     chdscd,parscd,      ...
                     obcflag, limits)
%--------------------------------------------------------------
%  Extract arbitrary variables from parent-ROMS history file
%  to save in boundary perimeter files on child-ROMS grid.
%
%  input
%  =====
%  par_grd:         parent grid .nc file name
%  chd_grd:         child grid .nc file name
%  chdscd:          child grid s-coordinate parameters (object)
%  parscd:          parent grid s-coordinate parameters (object)
%  obcflag:         open boundaries flag (1=open , [S E N W])
%
%  Inspired by Roms_tools (IRD).
%  Thanks to Pierrick, Patrick (IRD), Francois (UCLA), Yusuke (UCLA)
%  Heavily modified from French produce
%  Jeroen Molemaker (UCLA); nmolem@ucla.edu
%    Evan Mason (ULPGC), June 2007
%  modified from R2r_h, extract the coeff computation
%--------------------------------------------------------------
%

% Get S-coordinate params for child grid
  theta_b_c = chdscd.theta_b;
  theta_s_c = chdscd.theta_s;
  hc_c      = chdscd.hc;
  N_c       = chdscd.N;
  scoord_c  = chdscd.scoord;

% Get S-coordinate params for parent grid
  theta_b_p = parscd.theta_b;
  theta_s_p = parscd.theta_s;
  hc_p      = parscd.hc;
  N_p       = parscd.N;
  scoord_p  = parscd.scoord;

  nc = netcdf(chd_grd, 'nowrite');
  [mpc npc] = size(nc{'h'}(:));
  close(nc);

 for bnd = 1:4
  disp('-------------------------------------------------------------')
  if ~obcflag(bnd)
    disp('Closed boundary')
    continue
  end
  if bnd==1 
   disp('South boundary')
   i0 =  1; 
   i1 = npc;
   j0 = 1;
   j1 = 2;
   fcoef = 'r2r_coefs_south.mat';
  end
  if bnd==2 
   disp('East boundary')
   i0 = npc-1;
   i1 = npc;
   j0 = 1;
   j1 = mpc;
   fcoef = 'r2r_coefs_east.mat';
  end
  if bnd==3 
   disp('North boundary')
   i0 = 1;
   i1 = npc;
   j0 = mpc-1;
   j1 = mpc;
   fcoef = 'r2r_coefs_north.mat';
  end
  if bnd==4 
   disp('West boundary')
   i0 = 1;
   i1 = 2;
   j0 = 1;
   j1 = mpc;
   fcoef = 'r2r_coefs_west.mat';
  end

% Compute minimal subgrid extracted from parent grid
  imin = limits(bnd,1); imax = limits(bnd,2);
  jmin = limits(bnd,3); jmax = limits(bnd,4);

% Get topography data from childgrid
  nc = netcdf(chd_grd, 'nowrite');
  hc    = nc{'h'}(j0:j1,i0:i1);
  pm    = nc{'pm'}(j0:j1,i0:i1);       pn    = nc{'pn'}(j0:j1,i0:i1);
  maskc = nc{'mask_rho'}(j0:j1,i0:i1); angc  = nc{'angle'}(j0:j1,i0:i1);
  lonc  = nc{'lon_rho'}(j0:j1,i0:i1);  latc  = nc{'lat_rho'}(j0:j1,i0:i1);
  nc=close(nc);
  cosc  = cos(angc);         sinc  = sin(angc);

  [Mc,Lc] = size(maskc);
  maskc3d = zeros(N_c,Mc,Lc);
  for k = 1:N_c
   maskc3d(k,:,:) = maskc;
  end
  umask = maskc3d(:,:,2:end).*maskc3d(:,:,1:end-1);
  vmask = maskc3d(:,2:end,:).*maskc3d(:,1:end-1,:);

% Get parent grid and squeeze minimal subgrid
  np    = netcdf(par_grd, 'nowrite');
  masks = squeeze(np{'mask_rho'}(jmin:jmax, imin:imax));
  lons  = squeeze(np{'lon_rho'}(jmin:jmax, imin:imax)); 
  lats  = squeeze(np{'lat_rho'}(jmin:jmax, imin:imax));
  angs  = squeeze(np{'angle'}(jmin:jmax, imin:imax));
  hs    = squeeze(np{'h'}(jmin:jmax, imin:imax));
  np=close(np);
  coss = cos(angs); sins = sin(angs);
  if sum(isnan(masks))>0
      disp('Setting NaNs in masks to zero')
      masks(isnan(masks))=0;
      disp('You probably have land masking defined in cppdefs.h...')
  end

  % Z-coordinate (3D) on minimal subgrid and child grid
  % Sasha recommends the 0 multiplication
  zs = zlevs3(hs, hs*0, theta_s_p, theta_b_p, hc_p, N_p, 'r', scoord_p);
  zc = zlevs3(hc, hc*0, theta_s_c, theta_b_c, hc_c, N_c, 'r', scoord_c);
  zw = zlevs3(hc, hc*0, theta_s_c, theta_b_c, hc_c, N_c, 'w', scoord_c);

  [Np Mp Lp] = size(zs);
  [Nc Mc Lc] = size(zc);

  disp(' ')
  disp('Computing interpolation coefficients');
  [elem2d,coef2d,nnel] = get_tri_coef(lons,lats,lonc,latc,masks);

  A = get_hv_coef(zs, zc, coef2d, elem2d, lons, lats, lonc, latc);
  save(fcoef,'elem2d','coef2d','nnel','A')
  end

